/*
 * Copyright (C) 2000 - 2024 Silverpeas
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 *
 * As a special exception to the terms and conditions of version 3.0 of
 * the GPL, you may redistribute this Program in connection with Free/Libre
 * Open Source Software ("FLOSS") applications as described in Silverpeas's
 * FLOSS exception. You should have recieved a copy of the text describing
 * the FLOSS exception, and it is also available here:
 * "https://www.silverpeas.org/legal/floss_exception.html"
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with this program. If not, see <https://www.gnu.org/licenses/>.
 */

package org.silverpeas.processmanager;

/**
 * Thrown when a fatal error occured in a processManager component.
 */
public class ProcessManagerFatalException extends ProcessManagerException {

  private static final long serialVersionUID = 2449277163364832687L;

  /**
   * Set the caller and the error message
   */
  public ProcessManagerFatalException(String caller, String message) {
    super(caller, ERROR, message);
  }

  /**
   * Set the caller, the error message and the nested exception.
   */
  public ProcessManagerFatalException(String caller, String message, Exception nestedException) {
    super(caller, ERROR, message, nestedException);
  }

  /**
   * Set the caller, infos and the error message
   */
  public ProcessManagerFatalException(String caller, String message, String infos) {
    super(caller, ERROR, message, infos);
  }

  /**
   * Set the caller, the error message, infos and the nested exception.
   */
  public ProcessManagerFatalException(String caller, String message, String infos,
      Exception nestedException) {
    super(caller, ERROR, message, infos, nestedException);
  }
}
